@@ -1,53 +1,52 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #include "cut-enum-types.h"
 #include "cut-public.h"
-#include "cut-private.h"
-#include "cut-runner.h"
-#include "cut-run-context.h"
-#include "cut-test-runner.h"
-#include "cut-listener.h"
-#include "cut-listener-utils.h"
-#include "cut-main.h"
-#include "cut-test.h"
-#include "cut-iterated-test.h"
-#include "cut-test-container.h"
-#include "cut-test-iterator.h"
-#include "cut-test-case.h"
-#include "cut-test-suite.h"
-#include "cut-test-context.h"
-#include "cut-test-result.h"
-#include "cut-test-data.h"
-#include "cut-ui.h"
-#include "cut-contractor.h"
-#include "cut-factory-builder.h"
-#include "cut-report-factory-builder.h"
-#include "cut-stream-factory-builder.h"
-#include "cut-ui-factory-builder.h"
-#include "cut-module-factory.h"
-#include "cut-module-factory-utils.h"
-#include "cut-report.h"
-#include "cut-stream.h"
-#include "cut-process.h"
-#include "cut-pipeline.h"
-#include "cut-stream-parser.h"
-#include "cut-verbose-level.h"
-#include "cut-sequence-matcher.h"
-#include "cut-differ.h"
-#include "cut-diff-writer.h"
-#include "cut-string-diff-writer.h"
-#include "cut-console-diff-writer.h"
-#include "cut-readable-differ.h"
-#include "cut-unified-differ.h"
-#include "cut-colorize-differ.h"
-#include "cut-console.h"
 #include "cut-analyzer.h"
-#include "cut-stream-reader.h"
-#include "cut-file-stream-reader.h"
-#include "cut-sub-process.h"
-#include "cut-sub-process-group.h"
 #include "cut-backtrace-entry.h"
+#include "cut-colorize-differ.h"
+#include "cut-console-diff-writer.h"
+#include "cut-console.h"
+#include "cut-contractor.h"
+#include "cut-diff-writer.h"
+#include "cut-differ.h"
+#include "cut-factory-builder.h"
+#include "cut-file-stream-reader.h"
+#include "cut-iterated-test.h"
+#include "cut-listener-utils.h"
+#include "cut-listener.h"
+#include "cut-main.h"
+#include "cut-module-factory-utils.h"
+#include "cut-module-factory.h"
+#include "cut-pipeline.h"
+#include "cut-private.h"
+#include "cut-process.h"
+#include "cut-readable-differ.h"
+#include "cut-report-factory-builder.h"
+#include "cut-report.h"
+#include "cut-run-context.h"
+#include "cut-runner.h"
+#include "cut-stream-factory-builder.h"
+#include "cut-stream-parser.h"
+#include "cut-stream-reader.h"
+#include "cut-stream.h"
+#include "cut-string-diff-writer.h"
+#include "cut-sub-process-group.h"
+#include "cut-sub-process.h"
+#include "cut-test-case.h"
+#include "cut-test-container.h"
+#include "cut-test-context.h"
+#include "cut-test-data.h"
+#include "cut-test-iterator.h"
+#include "cut-test-result.h"
+#include "cut-test-runner.h"
+#include "cut-test-suite.h"
+#include "cut-test.h"
+#include "cut-ui-factory-builder.h"
+#include "cut-ui.h"
+#include "cut-unified-differ.h"
+#include "cut-verbose-level.h"
 
 /* enumerations from "cut-public.h" */
 GType
@@ -72,30 +71,42 @@ cut_test_result_status_get_type (void)
   return etype;
 }
 GType
-cut_order_get_type (void)
+cut_diff_writer_tag_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { CUT_ORDER_NONE_SPECIFIED, "CUT_ORDER_NONE_SPECIFIED", "none-specified" },
-      { CUT_ORDER_NAME_ASCENDING, "CUT_ORDER_NAME_ASCENDING", "name-ascending" },
-      { CUT_ORDER_NAME_DESCENDING, "CUT_ORDER_NAME_DESCENDING", "name-descending" },
+      { CUT_DIFF_WRITER_TAG_NONE, "CUT_DIFF_WRITER_TAG_NONE", "none" },
+      { CUT_DIFF_WRITER_TAG_SUMMARY, "CUT_DIFF_WRITER_TAG_SUMMARY", "summary" },
+      { CUT_DIFF_WRITER_TAG_CONTEXT, "CUT_DIFF_WRITER_TAG_CONTEXT", "context" },
+      { CUT_DIFF_WRITER_TAG_EQUAL_MARK, "CUT_DIFF_WRITER_TAG_EQUAL_MARK", "equal-mark" },
+      { CUT_DIFF_WRITER_TAG_DELETED_MARK, "CUT_DIFF_WRITER_TAG_DELETED_MARK", "deleted-mark" },
+      { CUT_DIFF_WRITER_TAG_INSERTED_MARK, "CUT_DIFF_WRITER_TAG_INSERTED_MARK", "inserted-mark" },
+      { CUT_DIFF_WRITER_TAG_DIFFERENCE_MARK, "CUT_DIFF_WRITER_TAG_DIFFERENCE_MARK", "difference-mark" },
+      { CUT_DIFF_WRITER_TAG_EQUAL_LINE, "CUT_DIFF_WRITER_TAG_EQUAL_LINE", "equal-line" },
+      { CUT_DIFF_WRITER_TAG_DELETED_LINE, "CUT_DIFF_WRITER_TAG_DELETED_LINE", "deleted-line" },
+      { CUT_DIFF_WRITER_TAG_INSERTED_LINE, "CUT_DIFF_WRITER_TAG_INSERTED_LINE", "inserted-line" },
+      { CUT_DIFF_WRITER_TAG_DIFFERENCE_LINE, "CUT_DIFF_WRITER_TAG_DIFFERENCE_LINE", "difference-line" },
+      { CUT_DIFF_WRITER_TAG_EQUAL_SEGMENT, "CUT_DIFF_WRITER_TAG_EQUAL_SEGMENT", "equal-segment" },
+      { CUT_DIFF_WRITER_TAG_DELETED_SEGMENT, "CUT_DIFF_WRITER_TAG_DELETED_SEGMENT", "deleted-segment" },
+      { CUT_DIFF_WRITER_TAG_INSERTED_SEGMENT, "CUT_DIFF_WRITER_TAG_INSERTED_SEGMENT", "inserted-segment" },
+      { CUT_DIFF_WRITER_TAG_DIFFERENCE_SEGMENT, "CUT_DIFF_WRITER_TAG_DIFFERENCE_SEGMENT", "difference-segment" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("CutOrder", values);
+    etype = g_enum_register_static ("CutDiffWriterTag", values);
   }
   return etype;
 }
 GType
-cut_test_context_error_get_type (void)
+cut_file_stream_reader_error_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { CUT_TEST_CONTEXT_ERROR_FATAL, "CUT_TEST_CONTEXT_ERROR_FATAL", "fatal" },
+      { CUT_FILE_STREAM_READER_ERROR_FILE, "CUT_FILE_STREAM_READER_ERROR_FILE", "file" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("CutTestContextError", values);
+    etype = g_enum_register_static ("CutFileStreamReaderError", values);
   }
   return etype;
 }
@@ -117,6 +128,50 @@ cut_pipeline_error_get_type (void)
   return etype;
 }
 GType
+cut_order_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_ORDER_NONE_SPECIFIED, "CUT_ORDER_NONE_SPECIFIED", "none-specified" },
+      { CUT_ORDER_NAME_ASCENDING, "CUT_ORDER_NAME_ASCENDING", "name-ascending" },
+      { CUT_ORDER_NAME_DESCENDING, "CUT_ORDER_NAME_DESCENDING", "name-descending" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutOrder", values);
+  }
+  return etype;
+}
+GType
+cut_stream_reader_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_STREAM_READER_ERROR_READ, "CUT_STREAM_READER_ERROR_READ", "read" },
+      { CUT_STREAM_READER_ERROR_PARSE, "CUT_STREAM_READER_ERROR_PARSE", "parse" },
+      { CUT_STREAM_READER_ERROR_END_PARSE, "CUT_STREAM_READER_ERROR_END_PARSE", "end-parse" },
+      { CUT_STREAM_READER_ERROR_IO_ERROR, "CUT_STREAM_READER_ERROR_IO_ERROR", "io-error" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutStreamReaderError", values);
+  }
+  return etype;
+}
+GType
+cut_test_context_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_TEST_CONTEXT_ERROR_FATAL, "CUT_TEST_CONTEXT_ERROR_FATAL", "fatal" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutTestContextError", values);
+  }
+  return etype;
+}
+GType
 cut_verbose_level_get_type (void)
 {
   static GType etype = 0;
@@ -145,78 +200,6 @@ cut_verbose_level_error_get_type (void)
   }
   return etype;
 }
-GType
-cut_sequence_match_operation_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { CUT_SEQUENCE_MATCH_OPERATION_EQUAL, "CUT_SEQUENCE_MATCH_OPERATION_EQUAL", "equal" },
-      { CUT_SEQUENCE_MATCH_OPERATION_INSERT, "CUT_SEQUENCE_MATCH_OPERATION_INSERT", "insert" },
-      { CUT_SEQUENCE_MATCH_OPERATION_DELETE, "CUT_SEQUENCE_MATCH_OPERATION_DELETE", "delete" },
-      { CUT_SEQUENCE_MATCH_OPERATION_REPLACE, "CUT_SEQUENCE_MATCH_OPERATION_REPLACE", "replace" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("CutSequenceMatchOperationType", values);
-  }
-  return etype;
-}
-GType
-cut_diff_writer_tag_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { CUT_DIFF_WRITER_TAG_NONE, "CUT_DIFF_WRITER_TAG_NONE", "none" },
-      { CUT_DIFF_WRITER_TAG_SUMMARY, "CUT_DIFF_WRITER_TAG_SUMMARY", "summary" },
-      { CUT_DIFF_WRITER_TAG_CONTEXT, "CUT_DIFF_WRITER_TAG_CONTEXT", "context" },
-      { CUT_DIFF_WRITER_TAG_EQUAL_MARK, "CUT_DIFF_WRITER_TAG_EQUAL_MARK", "equal-mark" },
-      { CUT_DIFF_WRITER_TAG_DELETED_MARK, "CUT_DIFF_WRITER_TAG_DELETED_MARK", "deleted-mark" },
-      { CUT_DIFF_WRITER_TAG_INSERTED_MARK, "CUT_DIFF_WRITER_TAG_INSERTED_MARK", "inserted-mark" },
-      { CUT_DIFF_WRITER_TAG_DIFFERENCE_MARK, "CUT_DIFF_WRITER_TAG_DIFFERENCE_MARK", "difference-mark" },
-      { CUT_DIFF_WRITER_TAG_EQUAL_LINE, "CUT_DIFF_WRITER_TAG_EQUAL_LINE", "equal-line" },
-      { CUT_DIFF_WRITER_TAG_DELETED_LINE, "CUT_DIFF_WRITER_TAG_DELETED_LINE", "deleted-line" },
-      { CUT_DIFF_WRITER_TAG_INSERTED_LINE, "CUT_DIFF_WRITER_TAG_INSERTED_LINE", "inserted-line" },
-      { CUT_DIFF_WRITER_TAG_DIFFERENCE_LINE, "CUT_DIFF_WRITER_TAG_DIFFERENCE_LINE", "difference-line" },
-      { CUT_DIFF_WRITER_TAG_EQUAL_SEGMENT, "CUT_DIFF_WRITER_TAG_EQUAL_SEGMENT", "equal-segment" },
-      { CUT_DIFF_WRITER_TAG_DELETED_SEGMENT, "CUT_DIFF_WRITER_TAG_DELETED_SEGMENT", "deleted-segment" },
-      { CUT_DIFF_WRITER_TAG_INSERTED_SEGMENT, "CUT_DIFF_WRITER_TAG_INSERTED_SEGMENT", "inserted-segment" },
-      { CUT_DIFF_WRITER_TAG_DIFFERENCE_SEGMENT, "CUT_DIFF_WRITER_TAG_DIFFERENCE_SEGMENT", "difference-segment" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("CutDiffWriterTag", values);
-  }
-  return etype;
-}
-GType
-cut_stream_reader_error_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { CUT_STREAM_READER_ERROR_READ, "CUT_STREAM_READER_ERROR_READ", "read" },
-      { CUT_STREAM_READER_ERROR_PARSE, "CUT_STREAM_READER_ERROR_PARSE", "parse" },
-      { CUT_STREAM_READER_ERROR_END_PARSE, "CUT_STREAM_READER_ERROR_END_PARSE", "end-parse" },
-      { CUT_STREAM_READER_ERROR_IO_ERROR, "CUT_STREAM_READER_ERROR_IO_ERROR", "io-error" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("CutStreamReaderError", values);
-  }
-  return etype;
-}
-GType
-cut_file_stream_reader_error_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { CUT_FILE_STREAM_READER_ERROR_FILE, "CUT_FILE_STREAM_READER_ERROR_FILE", "file" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("CutFileStreamReaderError", values);
-  }
-  return etype;
-}
 
-/* Generated data ends here */
+
 
