@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
+#include <glib-compatible/glib-compatible.h>
 
 #include "cut-repository.h"
 #include "cut-loader.h"
@@ -254,7 +255,8 @@ is_ignore_directory (const gchar *dir_name)
 static inline gchar *
 compute_relative_path (GArray *paths)
 {
-    gchar *last_component, *relative_path;
+    gchar *last_component = NULL;
+    gchar *relative_path;
     gboolean is_ignore_library_directory = FALSE;
 
     if (paths->len > 0) {
