@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,7 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <glib.h>
+#include <glib-compatible/glib-compatible.h>
 
 #include <string.h>
 
@@ -35,6 +36,10 @@
 #include "cut-enum-types.h"
 #include <gcutter/gcut-marshalers.h>
 
+#ifdef ERROR
+#  undef ERROR /* for Windows */
+#endif
+
 #if !GLIB_CHECK_VERSION(2, 18, 0)
 #  define g_set_error_literal(error, domain, code, message) \
     g_set_error(error, domain, code, "%s", message)
@@ -1316,7 +1321,7 @@ register_success_result (CutRunContext *context, CutTestResult *result)
 static void
 register_failure_result (CutRunContext *context, CutTestResult *result)
 {
-    CutRunContextPrivate *priv= CUT_RUN_CONTEXT_GET_PRIVATE(context);
+    CutRunContextPrivate *priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
 
     g_mutex_lock(priv->mutex);
     priv->results = g_list_prepend(priv->results, g_object_ref(result));
